.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center


Using Objects
:::::::::::::::::::::

In this unit, you will learn how to create and use objects in Java.

Class Periods: 13-15

AP CSA Exam Weighting: 5-7.5%

.. toctree::
   :caption: Unit 2 Table of Contents
   :maxdepth: 3

   topic-2-1-objects-intro-turtles.rst
   topic-2-2-constructors.rst
   topic-2-3-methods-no-params.rst
   topic-2-4-methods-with-params.rst
   topic-2-5-methods-return.rst
   topic-2-6-strings.rst
   topic-2-7-string-methods.rst
   topic-2-8-IntegerDouble.rst
   topic-2-9-Math.rst
   topic-2-10-summary.rst
   topic-2-11-practice-mixed-code.rst
   topic-2-11-practice-mixed-code-toggle.rst
   topic-2-12-practice-coding.rst
   practice-test-objects.rst
   Exercises.rst
   JavaSwingGUIs.rst

.. Old TOC
    whatIsJava.rst
   introClassObject.rst
   firstClass.rst
   compileTimeErrors.rst
   firstOOClass.rst
   runClass.rst
   partsOfAClass.rst
   JavaBasicsSummary.rst
